==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'L’adreça del vostre lloc', # MODIF
	'form_pet_aucune_signature' => 'No hi ha cap signatura que correspongui a aquest codi...', # MODIF
	'form_pet_confirmation' => 'Confirmeu la vostra signatura:',
	'form_pet_deja_signe' => 'Ja heu signat aquest text.',
	'form_pet_envoi_mail_confirmation' => 'Us acabem d’enviar un correu electrònic de confirmació a @email@. Heu d’anar a l’adreça Web que s’hi esmenta per validar la vostra signatura. ', # MODIF
	'form_pet_mail_confirmation' => 'Bon dia,

Heu sol·licitat signar la petició:
@titre@.

Heu facilitat les següents informacions:
    Nom: @nom_email@
    Lloc: @nom_site@ - @url_site@
    @message@

IMPORTANT...
Per validar la vostra signatura, heu de connectar-vos a l’adreça
indicada a continuació (en cas contrari, la sol·licitud serà
rebutjada) :

    @url@


Gràcies per la participació
',
	'form_pet_nom_site2' => 'Nom del vostre lloc Web', # MODIF
	'form_pet_probleme_liens' => 'Vulgueu reprendre el vostre missatge suprimint-ne els enllaços.',
	'form_pet_probleme_technique' => 'Problema tècnic, les signatures estan temporalment suspeses.',
	'form_pet_signature_validee' => 'La seva signatura ha estat validada. Gràcies!',
	'form_pet_site_deja_enregistre' => 'Aquest lloc està ja enregistrat',
	'form_pet_url_invalide' => 'L’URL que heu indicat no és vàlida.',
	'form_pet_votre_email' => 'Correu electrònic:',
	'form_pet_votre_nom' => 'El vostre nom o pseudònim', # MODIF
	'form_pet_votre_site' => 'Si teniu un lloc Web, podeu indicar-ho aquí sota',

	// I
	'info_adresse_email' => 'ADREÇA ELECTRÒNICA:',
	'info_signature_supprimee' => 'Signatura eliminada',
	'info_signature_supprimee_erreur' => 'Error: el codi de supressió no correspon a cap signatura', # MODIF
	'info_site_web' => 'LLOC WEB:',

	// L
	'lien_reponse_article' => 'Resposta a l’article'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activar la petició',
	'bouton_radio_pas_petition' => 'Cap petició',
	'bouton_radio_petition_activee' => 'Petició activada',
	'bouton_radio_supprimer_petition' => 'Suprimir la petició',

	// F
	'form_pet_adresse_site' => 'L’adreça del vostre lloc', # MODIF
	'form_pet_aucune_signature' => 'No hi ha cap signatura que correspongui a aquest codi...', # MODIF
	'form_pet_confirmation' => 'Confirmeu la vostra signatura:',
	'form_pet_deja_signe' => 'Ja heu signat aquest text.',
	'form_pet_envoi_mail_confirmation' => 'Us acabem d’enviar un correu electrònic de confirmació a @email@. Heu d’anar a l’adreça Web que s’hi esmenta per validar la vostra signatura. ', # MODIF
	'form_pet_mail_confirmation' => 'Bon dia,

Heu sol·licitat signar la petició:
@titre@.

Heu facilitat les següents informacions:
    Nom: @nom_email@
    Lloc: @nom_site@ - @url_site@
    @message@

IMPORTANT...
Per validar la vostra signatura, heu de connectar-vos a l’adreça
indicada a continuació (en cas contrari, la sol·licitud serà
rebutjada) :

    @url@


Gràcies per la participació
',
	'form_pet_nom_site2' => 'Nom del vostre lloc Web', # MODIF
	'form_pet_probleme_liens' => 'Vulgueu reprendre el vostre missatge suprimint-ne els enllaços.',
	'form_pet_probleme_technique' => 'Problema tècnic, les signatures estan temporalment suspeses.',
	'form_pet_signature_validee' => 'La seva signatura ha estat validada. Gràcies!',
	'form_pet_site_deja_enregistre' => 'Aquest lloc està ja enregistrat',
	'form_pet_url_invalide' => 'L’URL que heu indicat no és vàlida.',
	'form_pet_votre_email' => 'Correu electrònic:',
	'form_pet_votre_nom' => 'El vostre nom o pseudònim', # MODIF
	'form_pet_votre_site' => 'Si teniu un lloc Web, podeu indicar-ho aquí sota',

	// I
	'info_adresse_email' => 'ADREÇA ELECTRÒNICA:',
	'info_signature_supprimee' => 'Signatura eliminada',
	'info_signature_supprimee_erreur' => 'Error: el codi de supressió no correspon a cap signatura', # MODIF
	'info_site_web' => 'LLOC WEB:',

	// L
	'lien_reponse_article' => 'Resposta a l’article'
);

?>
